#
# $Id: VolumeHeader.pm,v 8.1 2004/05/17 13:04:09 wpm Exp $
#
# (c) 2003-2004 Morgan Stanley and Co.
# See ..../src/LICENSE for terms of distribution.
#

package AFS::Object::VolumeHeader;

use strict;

our @ISA = qw(AFS::Object);
our $VERSION = '1.7';

1;
